import{d as s,a7 as m,x as n,V as e,c as l,h as c,f as u,b as f}from"./index-VVnCDnWV.js";import{I as h}from"./ItemsListing-Bprv21nN.js";import"./VCheckbox-D12fUeu5.js";import"./eventbus-BIUJmFn6.js";import"./VListItem-Dw3eY18z.js";import"./VCheckboxBtn-cq8Dy8dF.js";import"./VList-DRt4eF-a.js";import"./VCardText-Dyx2_ozF.js";import"./VCard-Bs-wM7Pg.js";import"./VMenu-DCI9ln8Q.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./ListItem-Dv-oOSZ2.js";import"./Button-CWvXjESt.js";import"./VSpacer-DCHA2oNp.js";/* empty css              */import"./PanelviewItemCompact-Bkg8yvyq.js";import"./VAlert-CpEig3wP.js";import"./Container-CnTBixFv.js";import"./Toolbar-DRmVmE1x.js";import"./VToolbar-BfL0ebXm.js";import"./VTextField-DOex3sZA.js";import"./VInfiniteScroll-DagPdTI4.js";import"./layout-DOZ8cmRc.js";import"./VVirtualScroll-DzgdRVvk.js";const K=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),a=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),p=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":p,"sort-keys":["original","name","name_desc"],title:a.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{K as default};
